@@ -2,29 +2,29 @@ import itertools
 import operator
 from collections import OrderedDict
 from functools import reduce
-from warnings import warn
 
 import sympy as sp
 
 from lbmpy.maxwellian_equilibrium import (
-    compressible_to_incompressible_moment_value, get_cumulants_of_continuous_maxwellian_equilibrium,
-    get_moments_of_continuous_maxwellian_equilibrium,
+    compressible_to_incompressible_moment_value, get_equilibrium_values_of_maxwell_boltzmann_function,
     get_moments_of_discrete_maxwellian_equilibrium, get_weights)
 
-from lbmpy.methods.centeredcumulant.centered_cumulants import get_default_polynomial_cumulants_for_stencil
-from lbmpy.methods.momentbased.moment_transforms import PdfsToCentralMomentsByShiftMatrix
+from lbmpy.methods.abstractlbmethod import RelaxationInfo
+
+from lbmpy.methods.centeredcumulant import CenteredCumulantBasedLbMethod
 from lbmpy.methods.centeredcumulant.cumulant_transform import CentralMomentsToCumulantsByGeneratingFunc
 
-from lbmpy.methods.abstractlbmethod import RelaxationInfo
 from lbmpy.methods.conservedquantitycomputation import DensityVelocityComputation
-from lbmpy.methods.centeredcumulant import CenteredCumulantBasedLbMethod
+
 from lbmpy.methods.momentbased.momentbasedmethod import MomentBasedLbMethod
+from lbmpy.methods.momentbased.centralmomentbasedmethod import CentralMomentBasedLbMethod
+from lbmpy.moment_transforms import PdfsToCentralMomentsByShiftMatrix, PdfsToMomentsByChimeraTransform
 
 from lbmpy.moments import (
     MOMENT_SYMBOLS, discrete_moment, exponents_to_polynomial_representations,
     get_default_moment_set_for_stencil, gram_schmidt, is_even, moments_of_order,
     moments_up_to_component_order, sort_moments_into_groups_of_same_order,
-    is_bulk_moment, is_shear_moment, get_order)
+    is_bulk_moment, is_shear_moment, get_order, set_up_shift_matrix)
 
 from lbmpy.relaxationrates import relaxation_rate_from_magic_number
 from lbmpy.stencils import get_stencil
@@ -33,8 +33,10 @@ from pystencils.sympyextensions import common_denominator
 
 
 def create_with_discrete_maxwellian_eq_moments(stencil, moment_to_relaxation_rate_dict, compressible=False,
-                                               force_model=None, equilibrium_order=2,
-                                               cumulant=False, c_s_sq=sp.Rational(1, 3)):
+                                               force_model=None, equilibrium_order=2, c_s_sq=sp.Rational(1, 3),
+                                               central_moment_space=False,
+                                               moment_transform_class=None,
+                                               central_moment_transform_class=PdfsToCentralMomentsByShiftMatrix):
     r"""Creates a moment-based LBM by taking a list of moments with corresponding relaxation rate.
 
     These moments are relaxed against the moments of the discrete Maxwellian distribution.
@@ -50,11 +52,16 @@ def create_with_discrete_maxwellian_eq_moments(stencil, moment_to_relaxation_rat
                       compressible model.
         force_model: force model instance, or None if no external forces
         equilibrium_order: approximation order of macroscopic velocity :math:`\mathbf{u}` in the equilibrium
-        cumulant: if True relax cumulants instead of moments
         c_s_sq: Speed of sound squared
+        central_moment_space: If set to True, an instance of 
+                              :class:`lbmpy.methods.momentbased.CentralMomentBasedLbMethod` is returned, 
+                              and the the collision will be performed in the central moment space.
+        moment_transform_class: Class implementing the transform from populations to moment space.
+        central_moment_transform_class: Class implementing the transform from populations to central moment space.
 
     Returns:
-        `lbmpy.methods.momentbased.MomentBasedLbMethod` instance
+        Instance of either :class:`lbmpy.methods.momentbased.MomentBasedLbMethod` or 
+        :class:`lbmpy.methods.momentbased.CentralMomentBasedLbMethod` 
     """
     if isinstance(stencil, str):
         stencil = get_stencil(stencil)
@@ -64,61 +71,93 @@ def create_with_discrete_maxwellian_eq_moments(stencil, moment_to_relaxation_rat
 
     density_velocity_computation = DensityVelocityComputation(stencil, compressible, force_model)
 
-    if cumulant:
-        raise ValueError("Cumulant methods should be created with maxwellian_moments=True")
-    else:
-        eq_values = get_moments_of_discrete_maxwellian_equilibrium(stencil, tuple(mom_to_rr_dict.keys()),
-                                                                   c_s_sq=c_s_sq, compressible=compressible,
-                                                                   order=equilibrium_order)
+    moments = tuple(mom_to_rr_dict.keys())
+    eq_values = get_moments_of_discrete_maxwellian_equilibrium(stencil, moments,
+                                                               c_s_sq=c_s_sq, compressible=compressible,
+                                                               order=equilibrium_order)
+    if central_moment_space:
+        N = set_up_shift_matrix(moments, stencil)
+        eq_values = sp.simplify(N * sp.Matrix(eq_values))
 
     rr_dict = OrderedDict([(mom, RelaxationInfo(eq_mom, rr))
                            for mom, rr, eq_mom in zip(mom_to_rr_dict.keys(), mom_to_rr_dict.values(), eq_values)])
 
-    return MomentBasedLbMethod(stencil, rr_dict, density_velocity_computation, force_model)
+    if central_moment_space:
+        return CentralMomentBasedLbMethod(stencil, rr_dict, density_velocity_computation,
+                                          force_model, central_moment_transform_class)
+    else:
+        return MomentBasedLbMethod(stencil, rr_dict, density_velocity_computation, force_model, moment_transform_class)
 
 
 def create_with_continuous_maxwellian_eq_moments(stencil, moment_to_relaxation_rate_dict, compressible=False,
-                                                 force_model=None, equilibrium_order=2,
-                                                 cumulant=False, c_s_sq=sp.Rational(1, 3)):
+                                                 force_model=None, equilibrium_order=2, c_s_sq=sp.Rational(1, 3),
+                                                 central_moment_space=False,
+                                                 moment_transform_class=None,
+                                                 central_moment_transform_class=PdfsToCentralMomentsByShiftMatrix):
     r"""
     Creates a moment-based LBM by taking a list of moments with corresponding relaxation rate. These moments are
     relaxed against the moments of the continuous Maxwellian distribution.
     For parameter description see :func:`lbmpy.methods.create_with_discrete_maxwellian_eq_moments`.
     By using the continuous Maxwellian we automatically get a compressible model.
+
+    Args:
+        stencil: nested tuple defining the discrete velocity space. See `get_stencil`
+        moment_to_relaxation_rate_dict: dict that has as many entries as the stencil. Each moment, which can be
+                                        represented by an exponent tuple or in polynomial form
+                                        (see `lbmpy.moments`), is mapped to a relaxation rate.
+        compressible: incompressible LBM methods split the density into :math:`\rho = \rho_0 + \Delta \rho`
+                      where :math:`\rho_0` is chosen as one, and the first moment of the pdfs is :math:`\Delta \rho` .
+                      This approximates the incompressible Navier-Stokes equations better than the standard
+                      compressible model.
+        force_model: force model instance, or None if no external forces
+        equilibrium_order: approximation order of macroscopic velocity :math:`\mathbf{u}` in the equilibrium
+        c_s_sq: Speed of sound squared
+        central_moment_space: If set to True, an instance of 
+                              :class:`lbmpy.methods.momentbased.CentralMomentBasedLbMethod` is returned, 
+                              and the the collision will be performed in the central moment space.
+        moment_transform_class: Class implementing the transform from populations to moment space.
+        central_moment_transform_class: Class implementing the transform from populations to central moment space.
+
+    Returns:
+        Instance of either :class:`lbmpy.methods.momentbased.MomentBasedLbMethod` or 
+        :class:`lbmpy.methods.momentbased.CentralMomentBasedLbMethod` 
     """
     if isinstance(stencil, str):
         stencil = get_stencil(stencil)
     mom_to_rr_dict = OrderedDict(moment_to_relaxation_rate_dict)
-    assert len(mom_to_rr_dict) == len(stencil), "The number of moments has to be equal to the number of stencil entries"
-    dim = len(stencil[0])
+    assert len(mom_to_rr_dict) == stencil.Q, "The number of moments has to be equal to the number of stencil entries"
+    dim = stencil.D
     density_velocity_computation = DensityVelocityComputation(stencil, compressible, force_model)
+    moments = tuple(mom_to_rr_dict.keys())
 
-    if cumulant:
-        eq_values = get_cumulants_of_continuous_maxwellian_equilibrium(tuple(mom_to_rr_dict.keys()), dim, c_s_sq=c_s_sq,
-                                                                       order=equilibrium_order)
+    if compressible and central_moment_space:
+        eq_values = get_equilibrium_values_of_maxwell_boltzmann_function(moments, dim, c_s_sq=c_s_sq,
+                                                                         order=equilibrium_order,
+                                                                         space="central moment")
     else:
-        eq_values = get_moments_of_continuous_maxwellian_equilibrium(tuple(mom_to_rr_dict.keys()), dim, c_s_sq=c_s_sq,
-                                                                     order=equilibrium_order)
+        eq_values = get_equilibrium_values_of_maxwell_boltzmann_function(moments, dim, c_s_sq=c_s_sq,
+                                                                         order=equilibrium_order, space="moment")
 
     if not compressible:
-        if not compressible and cumulant:
-            raise NotImplementedError("Incompressible cumulants not yet supported")
         rho = density_velocity_computation.defined_symbols(order=0)[1]
         u = density_velocity_computation.defined_symbols(order=1)[1]
         eq_values = [compressible_to_incompressible_moment_value(em, rho, u) for em in eq_values]
+        if central_moment_space:
+            N = set_up_shift_matrix(moments, stencil)
+            eq_values = sp.simplify(N * sp.Matrix(eq_values))
 
     rr_dict = OrderedDict([(mom, RelaxationInfo(eq_mom, rr))
                            for mom, rr, eq_mom in zip(mom_to_rr_dict.keys(), mom_to_rr_dict.values(), eq_values)])
-    if cumulant:
-        warn("Please use method=cumulant directly to create a cumulant method", DeprecationWarning)
-        return create_with_default_polynomial_cumulants(stencil, mom_to_rr_dict.values(),
-                                                        force_model=force_model)
+
+    if central_moment_space:
+        return CentralMomentBasedLbMethod(stencil, rr_dict, density_velocity_computation,
+                                          force_model, central_moment_transform_class)
     else:
-        return MomentBasedLbMethod(stencil, rr_dict, density_velocity_computation, force_model)
+        return MomentBasedLbMethod(stencil, rr_dict, density_velocity_computation, force_model, moment_transform_class)
 
 
 def create_generic_mrt(stencil, moment_eq_value_relaxation_rate_tuples, compressible=False,
-                       force_model=None, cumulant=False):
+                       force_model=None, moment_transform_class=PdfsToMomentsByChimeraTransform):
     r"""
     Creates a generic moment-based LB method.
 
@@ -127,7 +166,6 @@ def create_generic_mrt(stencil, moment_eq_value_relaxation_rate_tuples, compress
         moment_eq_value_relaxation_rate_tuples: sequence of tuples containing (moment, equilibrium value, relax. rate)
         compressible: compressibility, determines calculation of velocity for force models
         force_model: see create_with_discrete_maxwellian_eq_moments
-        cumulant: true for cumulant methods, False for moment-based methods. Depricated parameter.
     """
     density_velocity_computation = DensityVelocityComputation(stencil, compressible, force_model)
 
@@ -135,14 +173,12 @@ def create_generic_mrt(stencil, moment_eq_value_relaxation_rate_tuples, compress
     for moment, eq_value, rr in moment_eq_value_relaxation_rate_tuples:
         moment = sp.sympify(moment)
         rr_dict[moment] = RelaxationInfo(eq_value, rr)
-    if cumulant:
-        warn("Please use method=cumulant directly to create a cumulant method", DeprecationWarning)
-        return CenteredCumulantBasedLbMethod(stencil, rr_dict, density_velocity_computation, force_model)
-    else:
-        return MomentBasedLbMethod(stencil, rr_dict, density_velocity_computation, force_model)
+    return MomentBasedLbMethod(stencil, rr_dict, density_velocity_computation, force_model, moment_transform_class)
 
 
-def create_from_equilibrium(stencil, equilibrium, moment_to_relaxation_rate_dict, compressible=False, force_model=None):
+def create_from_equilibrium(stencil, equilibrium, moment_to_relaxation_rate_dict,
+                            compressible=False, force_model=None,
+                            moment_transform_class=PdfsToMomentsByChimeraTransform):
     r"""
     Creates a moment-based LB method using a given equilibrium distribution function
 
@@ -166,7 +202,7 @@ def create_from_equilibrium(stencil, equilibrium, moment_to_relaxation_rate_dict
 
     rr_dict = OrderedDict([(mom, RelaxationInfo(discrete_moment(equilibrium, mom, stencil).expand(), rr))
                            for mom, rr in zip(mom_to_rr_dict.keys(), mom_to_rr_dict.values())])
-    return MomentBasedLbMethod(stencil, rr_dict, density_velocity_computation, force_model)
+    return MomentBasedLbMethod(stencil, rr_dict, density_velocity_computation, force_model, moment_transform_class)
 
 
 # ------------------------------------ SRT / TRT/ MRT Creators ---------------------------------------------------------
@@ -218,10 +254,19 @@ def create_trt(stencil, relaxation_rate_even_moments, relaxation_rate_odd_moment
 
 
 def create_trt_with_magic_number(stencil, relaxation_rate, magic_number=sp.Rational(3, 16), **kwargs):
-    """
+    r"""
     Creates a two relaxation time (TRT) lattice Boltzmann method, where the relaxation time for odd moments is
     determines from the even moment relaxation time and a "magic number".
     For possible parameters see :func:`lbmpy.methods.create_trt`
+
+    Args:
+        stencil: nested tuple defining the discrete velocity space. See :func:`lbmpy.stencils.get_stencil`
+        relaxation_rate: relaxation rate (inverse of the relaxation time)
+                        usually called :math:`\omega` in LBM literature
+        magic_number: magic number which is used to calculate the relxation rate for the odd moments.
+
+    Returns:
+        :class:`lbmpy.methods.momentbased.MomentBasedLbMethod` instance
     """
     rr_odd = relaxation_rate_from_magic_number(relaxation_rate, magic_number)
     return create_trt(stencil, relaxation_rate_even_moments=relaxation_rate,
@@ -229,7 +274,17 @@ def create_trt_with_magic_number(stencil, relaxation_rate, magic_number=sp.Ratio
 
 
 def create_mrt_raw(stencil, relaxation_rates, maxwellian_moments=False, **kwargs):
-    """Creates a MRT method using non-orthogonalized moments."""
+    r"""
+    Creates a MRT method using non-orthogonalized moments.
+
+    Args:
+        stencil: nested tuple defining the discrete velocity space. See :func:`lbmpy.stencils.get_stencil`
+        relaxation_rates: relaxation rates (inverse of the relaxation times) for each moment
+        maxwellian_moments: determines if the discrete or continuous maxwellian equilibrium is
+                        used to compute the equilibrium moments.
+    Returns:
+        :class:`lbmpy.methods.momentbased.MomentBasedLbMethod` instance
+    """
     if isinstance(stencil, str):
         stencil = get_stencil(stencil)
     moments = get_default_moment_set_for_stencil(stencil)
@@ -240,6 +295,65 @@ def create_mrt_raw(stencil, relaxation_rates, maxwellian_moments=False, **kwargs
         return create_with_discrete_maxwellian_eq_moments(stencil, rr_dict, **kwargs)
 
 
+def create_central_moment(stencil, relaxation_rates, nested_moments=None,
+                          maxwellian_moments=False, **kwargs):
+    r"""
+    Creates moment based LB method where the collision takes place in the central moment space.
+
+    Args:
+        stencil: nested tuple defining the discrete velocity space. See :func:`lbmpy.stencils.get_stencil`
+        relaxation_rates: relaxation rates (inverse of the relaxation times) for each moment
+        maxwellian_moments: determines if the discrete or continuous maxwellian equilibrium is
+                        used to compute the equilibrium moments.
+    Returns:
+        :class:`lbmpy.methods.momentbased.CentralMomentBasedLbMethod` instance
+    """
+    if isinstance(stencil, str):
+        stencil = get_stencil(stencil)
+
+    dim = len(stencil)
+
+    if nested_moments and not isinstance(nested_moments[0], list):
+        nested_moments = list(sort_moments_into_groups_of_same_order(nested_moments).values())
+        second_order_moments = nested_moments[2]
+        bulk_moment = [m for m in second_order_moments if is_bulk_moment(m, dim)]
+        shear_moments = [m for m in second_order_moments if is_shear_moment(m, dim)]
+        assert len(shear_moments) + len(bulk_moment) == len(second_order_moments)
+        nested_moments[2] = shear_moments
+        nested_moments.insert(3, bulk_moment)
+
+    if not nested_moments:
+        nested_moments = cascaded_moment_sets_literature(stencil)
+
+    if len(relaxation_rates) == 1:
+        r_rates = [relaxation_rates[0]]     # For correct viscosity
+        r_rates += [1] * (len(nested_moments) - 3)
+    else:
+        assert len(relaxation_rates) >= len(nested_moments) - 2, \
+            f"Number of relaxation rates must at least match the number of non-conserved moment groups. " \
+            f"For this stencil we have {len(nested_moments) - 2} such moment groups"
+        r_rates = relaxation_rates
+
+    rr_dict = OrderedDict()
+    rr_iter = iter(r_rates)
+    for group in nested_moments:
+        if all(get_order(c) <= 1 for c in group):
+            for moment in group:
+                rr_dict[moment] = 0
+        else:
+            try:
+                rr = next(rr_iter)
+                for moment in group:
+                    rr_dict[moment] = rr
+            except StopIteration:
+                raise ValueError('Not enough relaxation rates specified.')
+
+    if maxwellian_moments:
+        return create_with_continuous_maxwellian_eq_moments(stencil, rr_dict, central_moment_space=True, **kwargs)
+    else:
+        return create_with_discrete_maxwellian_eq_moments(stencil, rr_dict, central_moment_space=True, **kwargs)
+
+
 def create_trt_kbc(dim, shear_relaxation_rate, higher_order_relaxation_rate, method_name='KBC-N4',
                    maxwellian_moments=False, **kwargs):
     """
@@ -254,7 +368,7 @@ def create_trt_kbc(dim, shear_relaxation_rate, higher_order_relaxation_rate, met
         method_name: string 'KBC-Nx' where x can be an number from 1 to 4, for details see
                     "Karlin 2015: Entropic multi relaxation lattice Boltzmann models for turbulent flows"
         maxwellian_moments: determines if the discrete or continuous maxwellian equilibrium is
-                        used to compute the equilibrium moments
+                        used to compute the equilibrium moments.
     """
     def product(iterable):
         return reduce(operator.mul, iterable, 1)
@@ -366,12 +480,14 @@ def create_mrt_orthogonal(stencil, relaxation_rate_getter, maxwellian_moments=Fa
             moment_to_relaxation_rate_dict[m] = rr
 
     if maxwellian_moments:
-        return create_with_continuous_maxwellian_eq_moments(stencil, moment_to_relaxation_rate_dict, **kwargs)
+        return create_with_continuous_maxwellian_eq_moments(stencil,
+                                                            moment_to_relaxation_rate_dict, **kwargs)
     else:
-        return create_with_discrete_maxwellian_eq_moments(stencil, moment_to_relaxation_rate_dict, **kwargs)
+        return create_with_discrete_maxwellian_eq_moments(stencil,
+                                                          moment_to_relaxation_rate_dict, **kwargs)
 
 
-def mrt_orthogonal_modes_literature(stencil, is_weighted, is_cumulant=False):
+def mrt_orthogonal_modes_literature(stencil, is_weighted):
     """
     Returns a list of lists of modes, grouped by common relaxation times.
     This is for commonly used MRT models found in literature.
@@ -379,91 +495,220 @@ def mrt_orthogonal_modes_literature(stencil, is_weighted, is_cumulant=False):
     Args:
         stencil: nested tuple defining the discrete velocity space. See `get_stencil`
         is_weighted: whether to use weighted or unweighted orthogonality
-        is_cumulant: whether a moment-based or cumulant-based model is desired
 
     MRT schemes as described in the following references are used
     """
     x, y, z = MOMENT_SYMBOLS
     one = sp.Rational(1, 1)
 
-    if not is_cumulant:
-        if have_same_entries(stencil, get_stencil("D2Q9")) and is_weighted:
-            # Reference:
-            # Duenweg, B., Schiller, U. D., & Ladd, A. J. (2007). Statistical mechanics of the fluctuating
-            # lattice Boltzmann equation. Physical Review E, 76(3)
-            sq = x ** 2 + y ** 2
-            all_moments = [one, x, y, 3 * sq - 2, 2 * x ** 2 - sq, x * y,
-                           (3 * sq - 4) * x, (3 * sq - 4) * y, 9 * sq ** 2 - 15 * sq + 2]
-            nested_moments = list(sort_moments_into_groups_of_same_order(all_moments).values())
-            return nested_moments
-        elif have_same_entries(stencil, get_stencil("D3Q15")) and is_weighted:
-            sq = x ** 2 + y ** 2 + z ** 2
-            nested_moments = [
-                [one, x, y, z],  # [0, 3, 5, 7]
-                [sq - 1],  # [1]
-                [3 * sq ** 2 - 9 * sq + 4],  # [2]
-                [(3 * sq - 5) * x, (3 * sq - 5) * y, (3 * sq - 5) * z],  # [4, 6, 8]
-                [3 * x ** 2 - sq, y ** 2 - z ** 2, x * y, y * z, x * z],  # [9, 10, 11, 12, 13]
-                [x * y * z]
-            ]
-        elif have_same_entries(stencil, get_stencil("D3Q19")) and is_weighted:
-            # This MRT variant mentioned in the dissertation of Ulf Schiller
-            # "Thermal fluctuations and boundary conditions in the lattice Boltzmann method" (2008), p. 24ff
-            # There are some typos in the moment matrix on p.27
-            # The here implemented ordering of the moments is however different from that reference (Eq. 2.61-2.63)
-            # The moments are weighted-orthogonal (Eq. 2.58)
+    if have_same_entries(stencil, get_stencil("D2Q9")) and is_weighted:
+        # Reference:
+        # Duenweg, B., Schiller, U. D., & Ladd, A. J. (2007). Statistical mechanics of the fluctuating
+        # lattice Boltzmann equation. Physical Review E, 76(3)
+        sq = x ** 2 + y ** 2
+        all_moments = [one, x, y, 3 * sq - 2, 2 * x ** 2 - sq, x * y,
+                       (3 * sq - 4) * x, (3 * sq - 4) * y, 9 * sq ** 2 - 15 * sq + 2]
+        nested_moments = list(sort_moments_into_groups_of_same_order(all_moments).values())
+        return nested_moments
+    elif have_same_entries(stencil, get_stencil("D3Q15")) and is_weighted:
+        sq = x ** 2 + y ** 2 + z ** 2
+        nested_moments = [
+            [one, x, y, z],  # [0, 3, 5, 7]
+            [sq - 1],  # [1]
+            [3 * sq ** 2 - 9 * sq + 4],  # [2]
+            [(3 * sq - 5) * x, (3 * sq - 5) * y, (3 * sq - 5) * z],  # [4, 6, 8]
+            [3 * x ** 2 - sq, y ** 2 - z ** 2, x * y, y * z, x * z],  # [9, 10, 11, 12, 13]
+            [x * y * z]
+        ]
+    elif have_same_entries(stencil, get_stencil("D3Q19")) and is_weighted:
+        # This MRT variant mentioned in the dissertation of Ulf Schiller
+        # "Thermal fluctuations and boundary conditions in the lattice Boltzmann method" (2008), p. 24ff
+        # There are some typos in the moment matrix on p.27
+        # The here implemented ordering of the moments is however different from that reference (Eq. 2.61-2.63)
+        # The moments are weighted-orthogonal (Eq. 2.58)
 
-            # Further references:
-            # Duenweg, B., Schiller, U. D., & Ladd, A. J. (2007). Statistical mechanics of the fluctuating
-            # lattice Boltzmann equation. Physical Review E, 76(3)
-            # Chun, B., & Ladd, A. J. (2007). Interpolated boundary condition for lattice Boltzmann simulations of
-            # flows in narrow gaps. Physical review E, 75(6)
-            sq = x ** 2 + y ** 2 + z ** 2
-            nested_moments = [
-                [one, x, y, z],  # [0, 3, 5, 7]
-                [sq - 1],  # [1]
-                [3 * sq ** 2 - 6 * sq + 1],  # [2]
-                [(3 * sq - 5) * x, (3 * sq - 5) * y, (3 * sq - 5) * z],  # [4, 6, 8]
-                [3 * x ** 2 - sq, y ** 2 - z ** 2, x * y, y * z, x * z],  # [9, 11, 13, 14, 15]
-                [(2 * sq - 3) * (3 * x ** 2 - sq), (2 * sq - 3) * (y ** 2 - z ** 2)],  # [10, 12]
-                [(y ** 2 - z ** 2) * x, (z ** 2 - x ** 2) * y, (x ** 2 - y ** 2) * z]  # [16, 17, 18]
-            ]
-        elif have_same_entries(stencil, get_stencil("D3Q27")) and not is_weighted:
-            xsq, ysq, zsq = x ** 2, y ** 2, z ** 2
-            all_moments = [
-                sp.Rational(1, 1),  # 0
-                x, y, z,  # 1, 2, 3
-                x * y, x * z, y * z,  # 4, 5, 6
-                xsq - ysq,  # 7
-                (xsq + ysq + zsq) - 3 * zsq,  # 8
-                (xsq + ysq + zsq) - 2,  # 9
-                3 * (x * ysq + x * zsq) - 4 * x,  # 10
-                3 * (xsq * y + y * zsq) - 4 * y,  # 11
-                3 * (xsq * z + ysq * z) - 4 * z,  # 12
-                x * ysq - x * zsq,  # 13
-                xsq * y - y * zsq,  # 14
-                xsq * z - ysq * z,  # 15
-                x * y * z,  # 16
-                3 * (xsq * ysq + xsq * zsq + ysq * zsq) - 4 * (xsq + ysq + zsq) + 4,  # 17
-                3 * (xsq * ysq + xsq * zsq - 2 * ysq * zsq) - 2 * (2 * xsq - ysq - zsq),  # 18
-                3 * (xsq * ysq - xsq * zsq) - 2 * (ysq - zsq),  # 19
-                3 * (xsq * y * z) - 2 * (y * z),  # 20
-                3 * (x * ysq * z) - 2 * (x * z),  # 21
-                3 * (x * y * zsq) - 2 * (x * y),  # 22
-                9 * (x * ysq * zsq) - 6 * (x * ysq + x * zsq) + 4 * x,  # 23
-                9 * (xsq * y * zsq) - 6 * (xsq * y + y * zsq) + 4 * y,  # 24
-                9 * (xsq * ysq * z) - 6 * (xsq * z + ysq * z) + 4 * z,  # 25
-                27 * (xsq * ysq * zsq) - 18 * (xsq * ysq + xsq * zsq + ysq * zsq) + 12 * (xsq + ysq + zsq) - 8,  # 26
-            ]
-            nested_moments = list(sort_moments_into_groups_of_same_order(all_moments).values())
-        else:
-            raise NotImplementedError("No MRT model is available (yet) for this stencil. "
-                                      "Create a custom MRT using 'create_with_discrete_maxwellian_eq_moments'")
+        # Further references:
+        # Duenweg, B., Schiller, U. D., & Ladd, A. J. (2007). Statistical mechanics of the fluctuating
+        # lattice Boltzmann equation. Physical Review E, 76(3)
+        # Chun, B., & Ladd, A. J. (2007). Interpolated boundary condition for lattice Boltzmann simulations of
+        # flows in narrow gaps. Physical review E, 75(6)
+        sq = x ** 2 + y ** 2 + z ** 2
+        nested_moments = [
+            [one, x, y, z],  # [0, 3, 5, 7]
+            [sq - 1],  # [1]
+            [3 * sq ** 2 - 6 * sq + 1],  # [2]
+            [(3 * sq - 5) * x, (3 * sq - 5) * y, (3 * sq - 5) * z],  # [4, 6, 8]
+            [3 * x ** 2 - sq, y ** 2 - z ** 2, x * y, y * z, x * z],  # [9, 11, 13, 14, 15]
+            [(2 * sq - 3) * (3 * x ** 2 - sq), (2 * sq - 3) * (y ** 2 - z ** 2)],  # [10, 12]
+            [(y ** 2 - z ** 2) * x, (z ** 2 - x ** 2) * y, (x ** 2 - y ** 2) * z]  # [16, 17, 18]
+        ]
+    elif have_same_entries(stencil, get_stencil("D3Q27")) and not is_weighted:
+        xsq, ysq, zsq = x ** 2, y ** 2, z ** 2
+        all_moments = [
+            sp.Rational(1, 1),  # 0
+            x, y, z,  # 1, 2, 3
+            x * y, x * z, y * z,  # 4, 5, 6
+            xsq - ysq,  # 7
+            (xsq + ysq + zsq) - 3 * zsq,  # 8
+            (xsq + ysq + zsq) - 2,  # 9
+            3 * (x * ysq + x * zsq) - 4 * x,  # 10
+            3 * (xsq * y + y * zsq) - 4 * y,  # 11
+            3 * (xsq * z + ysq * z) - 4 * z,  # 12
+            x * ysq - x * zsq,  # 13
+            xsq * y - y * zsq,  # 14
+            xsq * z - ysq * z,  # 15
+            x * y * z,  # 16
+            3 * (xsq * ysq + xsq * zsq + ysq * zsq) - 4 * (xsq + ysq + zsq) + 4,  # 17
+            3 * (xsq * ysq + xsq * zsq - 2 * ysq * zsq) - 2 * (2 * xsq - ysq - zsq),  # 18
+            3 * (xsq * ysq - xsq * zsq) - 2 * (ysq - zsq),  # 19
+            3 * (xsq * y * z) - 2 * (y * z),  # 20
+            3 * (x * ysq * z) - 2 * (x * z),  # 21
+            3 * (x * y * zsq) - 2 * (x * y),  # 22
+            9 * (x * ysq * zsq) - 6 * (x * ysq + x * zsq) + 4 * x,  # 23
+            9 * (xsq * y * zsq) - 6 * (xsq * y + y * zsq) + 4 * y,  # 24
+            9 * (xsq * ysq * z) - 6 * (xsq * z + ysq * z) + 4 * z,  # 25
+            27 * (xsq * ysq * zsq) - 18 * (xsq * ysq + xsq * zsq + ysq * zsq) + 12 * (xsq + ysq + zsq) - 8,  # 26
+        ]
+        nested_moments = list(sort_moments_into_groups_of_same_order(all_moments).values())
     else:
-        nested_moments = get_default_polynomial_cumulants_for_stencil(stencil)
+        raise NotImplementedError("No MRT model is available (yet) for this stencil. "
+                                  "Create a custom MRT using 'create_with_discrete_maxwellian_eq_moments'")
 
     return nested_moments
 
+
+def cascaded_moment_sets_literature(stencil):
+    """
+    Returns default groups of cumulants to be relaxed with common relaxation rates as stated in literature.
+    Groups are ordered like this:
+
+    - First group is density
+    - Second group are the momentum modes
+    - Third group are the shear modes
+    - Fourth group is the bulk mode
+    - Remaining groups do not govern hydrodynamic properties
+
+    Args:
+        stencil: can be D2Q9, D2Q19 or D3Q27
+    """
+    x, y, z = MOMENT_SYMBOLS
+    if have_same_entries(stencil, get_stencil("D2Q9")):
+        #   Cumulants of the D2Q9 stencil up to third order are equal to
+        #   the central moments; only the fourth-order cumulant x**2 * y**2
+        #   has a more complicated form. They can be arranged into groups
+        #   for the preservation of rotational invariance as described by
+        #   Martin Geier in his dissertation.
+        #
+        #   Reference: Martin Geier. Ab inito derivation of the cascaded Lattice Boltzmann
+        #   Automaton. Dissertation. University of Freiburg. 2006.
+        return [
+            [sp.sympify(1)],        # density is conserved
+            [x, y],                 # momentum is relaxed for cumulant forcing
+
+            [x * y, x**2 - y**2],   # shear
+
+            [x**2 + y**2],          # bulk
+
+            [x**2 * y, x * y**2],
+            [x**2 * y**2]
+        ]
+
+    elif have_same_entries(stencil, get_stencil("D3Q15")):
+        #   D3Q15 central moments by Premnath et al. https://arxiv.org/pdf/1202.6081.pdf.
+        return [
+            [sp.sympify(1)],                # density is conserved
+            [x, y, z],                      # momentum might be affected by forcing
+
+            [x * y,
+             x * z,
+             y * z,
+             x ** 2 - y ** 2,
+             x ** 2 - z ** 2],              # shear
+
+            [x ** 2 + y ** 2 + z ** 2],     # bulk
+
+            [x * (x**2 + y**2 + z**2),
+             y * (x**2 + y**2 + z**2),
+             z * (x**2 + y**2 + z**2)],
+
+            [x * y * z],
+
+            [x ** 2 * y ** 2 + x ** 2 * z ** 2 + y ** 2 * z ** 2]
+        ]
+
+    elif have_same_entries(stencil, get_stencil("D3Q19")):
+        #   D3Q19 cumulants are obtained by pruning the D3Q27 cumulant set as
+        #   described by Coreixas, 2019.
+        return [
+            [sp.sympify(1)],                # density is conserved
+            [x, y, z],                      # momentum might be affected by forcing
+
+            [x * y,
+             x * z,
+             y * z,
+             x ** 2 - y ** 2,
+             x ** 2 - z ** 2],              # shear
+
+            [x ** 2 + y ** 2 + z ** 2],     # bulk
+
+            [x * y ** 2 + x * z ** 2,
+             x ** 2 * y + y * z ** 2,
+             x ** 2 * z + y ** 2 * z],
+
+            [x * y ** 2 - x * z ** 2,
+             x ** 2 * y - y * z ** 2,
+             x ** 2 * z - y ** 2 * z],
+
+            [x ** 2 * y ** 2 - 2 * x ** 2 * z ** 2 + y ** 2 * z ** 2,
+             x ** 2 * y ** 2 + x ** 2 * z ** 2 - 2 * y ** 2 * z ** 2],
+
+            [x ** 2 * y ** 2 + x ** 2 * z ** 2 + y ** 2 * z ** 2]
+        ]
+
+    elif have_same_entries(stencil, get_stencil("D3Q27")):
+        #   Cumulants grouped to preserve rotational invariance as described by Geier et al, 2015
+        return [
+            [sp.sympify(1)],                # density is conserved
+            [x, y, z],                      # momentum might be affected by forcing
+
+            [x * y,
+             x * z,
+             y * z,
+             x ** 2 - y ** 2,
+             x ** 2 - z ** 2],              # shear
+
+            [x ** 2 + y ** 2 + z ** 2],     # bulk
+
+            [x * y ** 2 + x * z ** 2,
+             x ** 2 * y + y * z ** 2,
+             x ** 2 * z + y ** 2 * z],
+
+            [x * y ** 2 - x * z ** 2,
+             x ** 2 * y - y * z ** 2,
+             x ** 2 * z - y ** 2 * z],
+
+            [x * y * z],
+
+            [x ** 2 * y ** 2 - 2 * x ** 2 * z ** 2 + y ** 2 * z ** 2,
+             x ** 2 * y ** 2 + x ** 2 * z ** 2 - 2 * y ** 2 * z ** 2],
+
+            [x ** 2 * y ** 2 + x ** 2 * z ** 2 + y ** 2 * z ** 2],
+
+            [x ** 2 * y * z,
+             x * y ** 2 * z,
+             x * y * z ** 2],
+
+            [x ** 2 * y ** 2 * z,
+             x ** 2 * y * z ** 2,
+             x * y ** 2 * z ** 2],
+
+            [x ** 2 * y ** 2 * z ** 2]
+        ]
+    else:
+        raise ValueError("No default set of cascaded moments is available for this stencil. "
+                         "Please specify your own set of cascaded moments.")
+
+
 # ----------------------------------------- Cumulant method creators ---------------------------------------------------
 
 
@@ -477,17 +722,16 @@ def create_centered_cumulant_model(stencil, cumulant_to_rr_dict, force_model=Non
     Args:
         stencil: nested tuple defining the discrete velocity space. See :func:`lbmpy.stencils.get_stencil`
         cumulant_to_rr_dict: dict that has as many entries as the stencil. Each cumulant, which can be
-                             represented by an exponent tuple or in polynomial form
-                             (see `lbmpy.methods.centeredcumulant.get_default_centered_cumulants_for_stencil`),
-                             is mapped to a relaxation rate.
+                             represented by an exponent tuple or in polynomial form is mapped to a relaxation rate.
+                             See `cascaded_moment_sets_literature`
         force_model: force model used for the collision. For cumulant LB method a good choice is
-                     `lbmpy.methods.centeredcumulant.force_model`
+                     `lbmpy.methods.centeredcumulant.CenteredCumulantForceModel`
         equilibrium_order: approximation order of macroscopic velocity :math:`\mathbf{u}` in the equilibrium
         c_s_sq: Speed of sound squared
         galilean_correction: special correction for D3Q27 cumulant collisions. See Appendix H in
                              :cite:`geier2015`. Implemented in :mod:`lbmpy.methods.centeredcumulant.galilean_correction`
         central_moment_transform_class: Class which defines the transformation to the central moment space
-                                        (see :mod:`lbmpy.methods.momentbased.moment_transforms`)
+                                        (see :mod:`lbmpy.moment_transforms`)
         cumulant_transform_class: Class which defines the transformation from the central moment space to the
                                   cumulant space (see :mod:`lbmpy.methods.centeredcumulant.cumulant_transform`)
 
@@ -517,8 +761,9 @@ def create_centered_cumulant_model(stencil, cumulant_to_rr_dict, force_model=Non
         cumulants_to_relaxation_info_dict[d] = RelaxationInfo(0, cumulant_to_rr_dict[d])
 
     #   Polynomial Cumulant Equilibria
-    polynomial_equilibria = get_cumulants_of_continuous_maxwellian_equilibrium(
-        higher_order_polynomials, dim, rho=density_symbol, u=velocity_symbols, c_s_sq=c_s_sq, order=equilibrium_order)
+    polynomial_equilibria = get_equilibrium_values_of_maxwell_boltzmann_function(
+        higher_order_polynomials, dim, rho=density_symbol, u=velocity_symbols,
+        c_s_sq=c_s_sq, order=equilibrium_order, space="cumulant")
     polynomial_equilibria = [density_symbol * v for v in polynomial_equilibria]
 
     for i, c in enumerate(higher_order_polynomials):
@@ -625,7 +870,7 @@ def create_with_default_polynomial_cumulants(stencil, relaxation_rates, **kwargs
         stencil = get_stencil(stencil)
 
     # Get polynomial groups
-    cumulant_groups = get_default_polynomial_cumulants_for_stencil(stencil)
+    cumulant_groups = cascaded_moment_sets_literature(stencil)
 
     if len(relaxation_rates) == 1:
         r_rates = [relaxation_rates[0]]     # For correct viscosity
